@@ -88,253 +88,253 @@ class TestScrapersAppendData:
         sources = [
             (
                 "#value+funding+required+usd+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#value+funding+total+usd+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#value+funding+pct+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#inneed+total+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#targeted+total+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#targeted+pct+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#reached+total+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#reached+pct+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#affected+food+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#affected+sam+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#affected+mam+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#affected+gam+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#affected+idps+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#affected+water+som",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/som-key-figures-2022",
             ),
             (
                 "#value+funding+required+usd+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#value+funding+total+usd+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#value+funding+pct+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#inneed+total+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#targeted+total+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#targeted+pct+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#reached+total+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#reached+pct+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#affected+food+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#affected+sam+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#affected+mam+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#affected+gam+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#affected+idps+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#affected+water+eth",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/eth-key-figures-2022",
             ),
             (
                 "#value+funding+required+usd+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#value+funding+total+usd+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#value+funding+pct+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#inneed+total+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#targeted+total+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#targeted+pct+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#reached+total+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#reached+pct+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#affected+food+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#affected+sam+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#affected+mam+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#affected+gam+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#affected+idps+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#affected+water+ken",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
@@ -421,85 +421,85 @@ class TestScrapersAppendData:
         sources = [
             (
                 "#value+funding+required+usd",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#value+funding+total+usd",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#value+funding+pct",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#inneed+total",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#targeted+total",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#targeted+pct",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#reached+total",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#reached+pct",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#affected+food",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#affected+sam",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#affected+mam",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#affected+gam",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#affected+idps",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
             (
                 "#affected+water",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/ken-key-figures-2022",
             ),
@@ -526,7 +526,7 @@ class TestScrapersAppendData:
         additional_sources.append(
             {
                 "indicator": "#value+funding+required+usd",
-                "source_date": "2020-10-01",
+                "source_date": "Oct 01, 2020",
                 "source": "multiple",
                 "source_url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             }
@@ -539,91 +539,91 @@ class TestScrapersAppendData:
         )
         assert jsonout.json["sources_data"] == [
             {
-                "#date": "2022-02-24",
+                "#date": "Feb 24, 2022",
                 "#indicator+name": "#date+start+conflict",
                 "#meta+source": "Meduza",
                 "#meta+url": "https://meduza.io/en/news/2022/02/24/putin-announces-start-of-military-operation-in-eastern-ukraine",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#value+funding+required+usd",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#value+funding+total+usd",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#value+funding+pct",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#inneed+total",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#targeted+total",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#targeted+pct",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#reached+total",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#reached+pct",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#affected+food",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#affected+sam",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#affected+mam",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#affected+gam",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#affected+idps",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
             },
             {
-                "#date": "2020-10-01",
+                "#date": "Oct 01, 2020",
                 "#indicator+name": "#affected+water",
                 "#meta+source": "multiple",
                 "#meta+url": "https://data.humdata.org/dataset/ken-key-figures-2022",
